import { ArrayValidator, FormArrayInit, FormArrayState, FormControlInit, FormControlState, FormControls, FormGroupInit, FormGroupState, GroupValidator } from './types';
/**
 * Initializes a new `FormControlState`.
 * @see `FormControlInit`
 *
 * @example
 * initFormControl(['value', [validator]])
 * initFormControl({value: 'value', validators: [validator], disabled: true, ...})
 */
export declare function initFormControl<T>(initial: FormControlInit<T>): FormControlState<T>;
/**
 * Initializes a new `FormGroupState`.
 * @param controls An object containing control initializations.
 * @param validators An array of GroupValidators which will be used for additional error detection.
 * @see `FormGroupInit`, `GroupValidator`
 *
 * @example
 * initFormGroup({
 *  firstControl: ['firstValue', [validator]],
 *  secondControl: {value: 'value', validators: [validator], disabled: true, ...}
 * })
 */
export declare function initFormGroup<TControls extends FormControls>(controls: FormGroupInit<TControls>, validators?: GroupValidator<TControls>[]): FormGroupState<TControls>;
/**
 * Initializes a new `FormArrayState`.
 * @param controls An object containing control initializations.
 * @param validators An array of ArrayValidators which will be used for additional error detection.
 * @see `FormArrayInit`, `ArrayValidator`
 *
 * @example
 * initFormArray(
 *  [
 *      ['firstValue', [validator]],
 *      {value: 'value', validators: [validator], disabled: true, ...}
 *  ],
 *  [arrayValidator])
 */
export declare function initFormArray<T>(initial: FormArrayInit<T>, validators?: ArrayValidator<T>[]): FormArrayState<T>;
